setwd("D:/github/jasss")
library(sf)
library(tidyverse)
# Read Shape File
seoul <- st_read("GIS/studyarea.shp") #Projection: 5181
attr(seoul, "sf_column")
#seoul_df <- as.data.frame(seoul)
#class(seoul_df)

# Read population data
pop.temp <- read_csv("GIS/KOSIS_age.csv")
colnames(pop.temp) <- c("gu", "dong", "groups", "pop")
pop.temp1 <- pop.temp %>% reshape2::dcast(gu + dong ~ groups, fun.aggregate = sum)
pop.temp2 <- pop.temp1 %>% mutate(under15new = under15 - under4)
pop <- pop.temp2 %>% select(gu, dong, under15new, btw1564, over65) %>%
        rename(under15 = under15new) %>% mutate(total = under15 + btw1564 + over65)

rm(list=setdiff(ls(), c("pop","seoul")))

# join population to shapefile
seoul <- merge(seoul, pop, by.x = "adm_dr_nm", by.y = "dong")
plot(seoul[9:12])

##########
# ggplot #
##########
# 1. When you have plots that have high data variance
tot <- ggplot() + geom_sf(data = seoul, aes(fill = total)) + 
                  scale_fill_gradient(high = "springgreen4", low= "grey90", name="Total pop", 
                  labels = c("40,000", "30,000", "20,000", "10,000"),
                  breaks = c(40000, 30000, 20000, 10000))
u15 <- ggplot() + geom_sf(data = seoul, aes(fill = under15)) + 
                  scale_fill_gradient(high = "gold", low= "grey90", name="Under 15", 
                  labels = c("5,000","4,000", "3,000", "2,000", "1,000"),
                  breaks = c(5000,4000, 3000, 2000, 1000))
btw1564 <- ggplot() + geom_sf(data = seoul, aes(fill = btw1564)) + 
                  scale_fill_gradient(high = "orangered1", low= "grey90", name="15-64", 
                  labels = c("40,000", "30,000", "20,000", "10,000"),
                  breaks = c(40000, 30000, 20000, 10000))
over65 <- ggplot() + geom_sf(data = seoul, aes(fill = over65)) + 
                  scale_fill_gradient(high = "slateblue2", low= "grey90", name="Over 65", 
                  labels = c("4,000", "3,000", "2,000", "1,000"),
                  breaks = c(4000, 3000, 2000, 1000))
library(cowplot)
plot_grid(tot, u15, btw1564, over65, nrow=2)
ggsave(filename="d:/population.png", width = 10, height = 7, units = "in", dpi = 300)

# 2. Normal: will close for now
#seoul2 <- seoul %>% select(total, under15, btw1564, over65, geometry) %>% gather(VAR, POP, -geometry)
#seoul2 %>% ggplot() + geom_sf(aes(fill = POP)) + scale_fill_gradient(low = "#56B1F7", high = "#132B43") +
#  facet_wrap(~VAR, ncol = 2)




